@@ -20,6 +20,62 @@ def test_regression_9():
     builder = pjs.ObjectBuilder(schema)
     builder.build_classes()
 
+def test_arrays_can_have_reffed_items_of_mixed_type():
+    schema = {
+            "$schema": "http://json-schema.org/schema#",
+            "id": "test",
+            "type": "object",
+            "properties": {
+                "list": {
+                    "type": "array",
+                    "items": {"oneOf": [
+                        {"$ref": "#/definitions/foo"},
+                        {
+                            "type": "object",
+                            "properties": {
+                                "bar": {"type":"string"}
+                                },
+                            "required": ["bar"]
+                        }
+                        ]},
+                    }
+                },
+            "definitions": {
+                "foo": {
+                    "type": "string"
+                    }
+                }
+            }
+    builder = pjs.ObjectBuilder(schema)
+    ns = builder.build_classes()
+
+    ns.Test(list=["foo", "bar"])
+    ns.Test(list=[{"bar": "nice"}, "bar"])
+    with pytest.raises(pjs.ValidationError):
+        ns.Test(list=[100])
+
+
+def test_regression_39():
+    builder = pjs.ObjectBuilder("test/thing-two.json")
+    ns = builder.build_classes()
+
+    for thing in ('BarMessage', 'BarGroup', "Bar", "Header"):
+        assert thing in ns
+
+    x = ns.BarMessage(id="message_id",
+                      title="my bar group",
+                      bars=[{"name": "Freddies Half Shell"}]
+                      )
+
+    x.validate()
+
+    # Now an invalid one 
+    with pytest.raises(pjs.ValidationError):
+        ns.BarMessage(id="message_id",
+                      title="my bar group",
+                      bars=[{"Address": "I should have a name"}]
+                      )
+
 
 def test_loads_markdown_schema_extraction(markdown_examples):
     assert 'Other' in markdown_examples
